# ifndef yyGlobalComm
# define yyGlobalComm

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* GlobalComm_Exit) ARGS ((void));

extern tTree GlobalCommunication ARGS ((tTree stmt));

extern void BeginGlobalComm ARGS ((void));
extern void CloseGlobalComm ARGS ((void));

# endif
